runner

package
v1.4.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 5, 2026 License: MIT Imports: 19 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

AllSources are used to store all available sources

Functions

func ListSources added in v1.1.2

func ListSources()

ListSources prints all available sources to stdout.

func UnmarshalFrom added in v0.1.0

func UnmarshalFrom(file string) error

UnmarshalFrom writes the marshaled yaml config to disk

func WriteJSONResult added in v1.2.0

func WriteJSONResult(writer io.Writer, result *sources.Result, target string) error

func WritePlainResult added in v0.1.0

func WritePlainResult(writer io.Writer, verbose bool, result *sources.Result) error

Types

type Options

type Options struct {
	Debug           bool
	Insecure        bool // Insecure disables TLS certificate verification when true
	JSON            bool // JSON outputs results as JSONL (one JSON object per line)
	ListSources     bool
	NoDeduplication bool // NoDeduplication disables deduplication of results across sources
	NoFilter        bool
	NoRateLimit     bool
	Output          io.Writer
	OutputFile      string
	Overwrite       bool
	ProviderConfig  string // ProviderConfig contains the location of the provider config file
	Proxy           string
	Quiet           bool
	Sources         []string
	Stdin           bool
	Targets         string
	Timeout         time.Duration
	Type            sources.ScanType
	UserAgent       string
	Verbose         bool
	Verify          bool // Verify enriches results with HIBP password checks and hash identification
	Version         string
}

Options struct is used to store leaker options. Sort alphabetically

func (*Options) ConfigureOutput added in v0.1.0

func (options *Options) ConfigureOutput()

ConfigureOutput configures the output on the screen

type Runner

type Runner struct {
	// contains filtered or unexported fields
}

func NewRunner

func NewRunner(options *Options) (*Runner, error)

NewRunner creates a new runner struct instance by parsing the configuration options, configuring sources, reading lists and setting up loggers, etc.

func (*Runner) EnumerateMultipleTargets added in v1.1.1

func (r *Runner) EnumerateMultipleTargets(ctx context.Context, reader io.Reader, writers []io.Writer) error

func (*Runner) EnumerateSingleTarget added in v1.1.1

func (r *Runner) EnumerateSingleTarget(ctx context.Context, target string, scanType sources.ScanType, timeout time.Duration, writers []io.Writer) error

func (*Runner) RunEnumeration

func (r *Runner) RunEnumeration(ctx context.Context) error

type Verifier added in v1.4.0

type Verifier struct {
	// contains filtered or unexported fields
}

Verifier enriches results with HIBP password breach counts and hash type identification.

func NewVerifier added in v1.4.0

func NewVerifier(enabled bool) *Verifier

NewVerifier creates a new Verifier. When enabled is false, EnrichResult is a no-op.

func (*Verifier) EnrichResult added in v1.4.0

func (v *Verifier) EnrichResult(result *sources.Result)

EnrichResult enriches a Result in-place with verification signals.

Directories

Path Synopsis

Jump to