Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
var AllSources = [...]sources.Source{ &sources.BreachDirectory{}, &sources.DeHashed{}, &sources.HudsonRock{}, &sources.IntelX{}, &sources.LeakCheck{}, &sources.LeakLookup{}, &sources.LeakSight{}, &sources.OSINTLeak{}, &sources.ProxyNova{}, &sources.Snusbase{}, &sources.WeLeakInfo{}, &sources.WhiteIntel{}, }
AllSources are used to store all available sources
Functions ¶
func ListSources ¶ added in v1.1.2
func ListSources()
ListSources prints all available sources to stdout.
func UnmarshalFrom ¶ added in v0.1.0
UnmarshalFrom writes the marshaled yaml config to disk
func WriteJSONResult ¶ added in v1.2.0
Types ¶
type Options ¶
type Options struct {
Debug bool
Insecure bool // Insecure disables TLS certificate verification when true
JSON bool // JSON outputs results as JSONL (one JSON object per line)
ListSources bool
NoDeduplication bool // NoDeduplication disables deduplication of results across sources
NoFilter bool
NoRateLimit bool
Output io.Writer
OutputFile string
Overwrite bool
ProviderConfig string // ProviderConfig contains the location of the provider config file
Proxy string
Quiet bool
Sources []string
Stdin bool
Targets string
Timeout time.Duration
Type sources.ScanType
UserAgent string
Verbose bool
Verify bool // Verify enriches results with HIBP password checks and hash identification
Version string
}
Options struct is used to store leaker options. Sort alphabetically
func (*Options) ConfigureOutput ¶ added in v0.1.0
func (options *Options) ConfigureOutput()
ConfigureOutput configures the output on the screen
type Runner ¶
type Runner struct {
// contains filtered or unexported fields
}
func NewRunner ¶
NewRunner creates a new runner struct instance by parsing the configuration options, configuring sources, reading lists and setting up loggers, etc.
func (*Runner) EnumerateMultipleTargets ¶ added in v1.1.1
func (*Runner) EnumerateSingleTarget ¶ added in v1.1.1
type Verifier ¶ added in v1.4.0
type Verifier struct {
// contains filtered or unexported fields
}
Verifier enriches results with HIBP password breach counts and hash type identification.
func NewVerifier ¶ added in v1.4.0
NewVerifier creates a new Verifier. When enabled is false, EnrichResult is a no-op.
func (*Verifier) EnrichResult ¶ added in v1.4.0
EnrichResult enriches a Result in-place with verification signals.
Source Files
¶
Click to show internal directories.
Click to hide internal directories.